﻿// Copyright (c) 2024, itsdave GmbH and contributors
// For license information, please see license.txt

frappe.listview_settings.Tracker = {
    button: {
        show: function (doc) {
            return true;
        },
        get_label: function () {
            return __('🗺️ Show Trips');
        },
        get_description: function (doc) {
            return __('Show trip for {0}', [doc.name]);
        },
        action: function (doc) {
            // Função para abrir um modal de filtros
            const openDateFilterModal = () => {
                const options = [
                    { label: __('Today'), value: 'today' },
                    { label: __('Yesterday'), value: 'yesterday' },
                    { label: __('Last Week'), value: 'last_week' },
                    { label: __('Current Month'), value: 'current_month' },
                    { label: __('Custom'), value: 'custom' }
                ];
                const defaultOption = 'today';

                const fields = [
                    {
                        label: __('Select Date Range'),
                        fieldtype: 'Select',
                        fieldname: 'date_range',
                        options: options.map(option => option.label),
                        onchange: function () {
                            const selectedOption = options.find(
                                option => option.label === this.value
                            );
                            toggleCustomDateFields(selectedOption.value === 'custom', dialog);
                        }
                    },
                    // Fields hidden for custom date selection that will be shown when 'Custom' is selected
                    {
                        label: __('Start Date'),
                        fieldtype: 'Date',
                        fieldname: 'start_date',
                        depends_on: 'eval:doc.date_range=="Custom"'
                    },
                    {
                        label: __('End Date'),
                        fieldtype: 'Date',
                        fieldname: 'end_date',
                        depends_on: 'eval:doc.date_range=="Custom"'
                    },
                ];

                const dialog = new frappe.ui.Dialog({
                    title: __('Select Date Range'),
                    fields: fields,
                    primary_action_label: __('Apply Filter'),
                    primary_action: function (values) {
                        if (values.date_range === 'Custom' && values.start_date && values.end_date) {
                            applyDateFilter('custom', values.start_date, values.end_date);
                        } else {
                            const selectedOption = options.find(
                                option => option.label === values.date_range
                            );
                            applyDateFilter(selectedOption.value);
                        }
                        dialog.hide();
                    }
                });
                dialog.show();

                function toggleCustomDateFields(show, dialog) {
                    const startField = dialog.fields_dict.start_date.$wrapper;
                    const endField = dialog.fields_dict.end_date.$wrapper;
                    if (show) {
                        startField.show();
                        endField.show();
                    } else {
                        startField.hide();
                        endField.hide();
                    }
                }

                const applyDateFilter = (filterValue, startDate, endDate) => {
                    // Logica para definir startDate e endDate com base no filterValue
                    switch (filterValue) {
                        case 'today':
                            startDate = moment().subtract(1, 'days').format('YYYY-MM-DD 23:00:00');
                            endDate = moment().format('YYYY-MM-DD 23:59:59');
                            break;
                        case 'yesterday':
                            startDate = moment().subtract(2, 'days').format('YYYY-MM-DD 23:00:00');
                            endDate = moment().subtract(1, 'days').format('YYYY-MM-DD 23:59:59');
                            break;
                        case 'last_week':
                            startDate = moment().subtract(7, 'days').format('YYYY-MM-DD 23:00:00');
                            endDate = moment().format('YYYY-MM-DD 23:59:59');
                            break;
                        case 'current_month':
                            startDate = moment().subtract(30, 'days').format('YYYY-MM-DD 23:00:00');
                            endDate = moment().format('YYYY-MM-DD 23:59:59');
                            break;
                        case 'custom':
                            startDate = moment(startDate).format('YYYY-MM-DD 23:00:00');
                            endDate = moment(endDate).format('YYYY-MM-DD 23:59:59');
                            break;
                    }

                    // Let's redirect to the Trip list view with the selected filters
                    frappe.set_route('List', 'Trip', {
                        'device_id': doc.portal_id,
                        'start': ['>=', startDate],
                        'end': ['<=', endDate]
                    });
                };
            };

            // Chamada para abrir o modal de filtros
            openDateFilterModal();
        }
    },

    onload(listview) {
        listview.page.add_inner_button('Sync devices', function () {
            frappe.call({
                method: 'fleet_management.traccar_api.get_devices',
                callback: function (r) {
                    if (!r.exc) {
                        location.reload();
                    }
                }
            });
        });
    }
};
